@@ -5,7 +5,10 @@ from typing import List, Optional, Tuple
 
 import pandas as pd
 
-from fastapi_generator.data import space, orm_type_mapping, python_type_mapping, pydantic_type_mapping
+from fastapi_generator.data import (
+    space, orm_type_mapping, python_type_mapping,
+    pydantic_type_mapping, tortoise_type_mapping, orm_field_options, tortoise_field_options
+)
 
 
 class FileMixin:
@@ -47,10 +50,13 @@ class Creation(FileMixin, TableMixin):
     db_name: str
     engine: any
     file: Path
-    _rows: Tuple[str] = field(default_factory=tuple)
+    rows: Tuple[str] = field(default_factory=tuple)
+    col_prefix: str = ''
+    type_mapping: dict = field(default_factory=dict)
+    field_options: dict = field(default_factory=dict)
 
     def generate(self):
-        self.write_rows(file=self.file, mode='w', rows=self._rows)
+        self.write_rows(file=self.file, mode='w', rows=self.rows)
         tables = self.read_tables(db_name=self.db_name, engine=self.engine)
         tables.groupby('TABLE_NAME').apply(self._make_from_table)
 
@@ -65,46 +71,28 @@ class Creation(FileMixin, TableMixin):
         self.write_rows(file=self.file, mode='a', row='\n')
 
     def _make_field(self, col: pd.Series):
-        the_field = self._generate_field(col)
+        the_field = self.generate_field(col)
         self.write_rows(file=self.file, mode='a', row=the_field)
 
     @abstractmethod
     def _class_rows(self, tb_name: str) -> Tuple[str]:
         """"""
 
-    @abstractmethod
-    def _generate_field(self, col: pd.Series) -> str:
-        """"""
+    @staticmethod
+    def _is_param_first(params: list):
+        """Only used to determine whether the parameter is the first parameter of the field."""
+        return len(params) <= 1
 
-
-@dataclass
-class OrmCreation(Creation):
-    """Used to generate orm for tables."""
-    _rows: Tuple[str] = (
-        "import orm",
-        "import sqlalchemy\n",
-        "from app.db import database\n",
-        "metadata = sqlalchemy.MetaData()\n\n"
-    )
-
-    def _class_rows(self, tb_name: str) -> Tuple[str]:
-        return (
-            f"class {self.count_model_name(tb_name=tb_name)}(orm.Model):",
-            f'{space * 4}__tablename__ = "{tb_name}"',
-            f'{space * 4}__database__ = database',
-            f'{space * 4}__metadata__ = metadata\n'
-        )
-
-    def _generate_field(self, col: pd.Series) -> str:
+    def generate_field(self, col: pd.Series) -> str:
         params = []
         col_name: str = col['COLUMN_NAME']
         col_type = col['DATA_TYPE']
-        res = f"{space * 4}{col_name} = orm.{orm_type_mapping[col_type]}()"
+        res = f"{space * 4}{col_name} = {self.col_prefix}.{self.type_mapping[col_type]}()"
 
         is_null = col['IS_NULLABLE'] == 'YES'  # Set the default to None
         if is_null:
             params.append(is_null)
-            null_str = f"allow_null={is_null},"
+            null_str = f"{self.field_options['IS_NULLABLE']}={is_null},"
             res = self.combine_param(res=res, param_str=null_str, is_first=self._is_param_first(params))
 
         # default has (null, CURRENT_TIMESTAMP, int, float, empty str, str)
@@ -112,7 +100,10 @@ class OrmCreation(Creation):
         if col_default is not None and col_default != 'CURRENT_TIMESTAMP':  # only set int/float/str
             params.append(col_default)
             default_val = python_type_mapping[col_type](col_default)
-            default_str = f"default='{default_val}'," if isinstance(default_val, str) else f"default={default_val},"
+            if isinstance(default_val, str):
+                default_str = f"{self.field_options['COLUMN_DEFAULT']}='{default_val}',"
+            else:
+                default_str = f"{self.field_options['COLUMN_DEFAULT']}={default_val},"
             res = self.combine_param(res=res, param_str=default_str, is_first=self._is_param_first(params))
 
         # keys has (MUL PRI UNI)
@@ -120,17 +111,17 @@ class OrmCreation(Creation):
         if col_key:  # cannot handle foreignkey
             if col_key == 'UNI':
                 params.append(col_key)
-                unique_str = f"unique=True,"
+                unique_str = f"{self.field_options['UNI']}=True,"
                 res = self.combine_param(res=res, param_str=unique_str, is_first=self._is_param_first(params))
 
             elif col_key == 'PRI':
                 params.append(col_key)
-                pk_str = f"primary_key=True,"
+                pk_str = f"{self.field_options['PRI']}=True,"
                 res = self.combine_param(res=res, param_str=pk_str, is_first=self._is_param_first(params))
 
             elif col_key == 'MUL':
                 foreign_name = f"{col_name[:-3]}s".capitalize()
-                foreign_key_str = f"{space * 4}# {col_name[:-3]}=orm.ForeignKey({foreign_name})"
+                foreign_key_str = f"{space * 4}# {col_name[:-3]}={self.col_prefix}.ForeignKey({foreign_name})"
                 self.write_rows(file=self.file, mode='a', row=foreign_key_str)
 
         # str len
@@ -138,7 +129,7 @@ class OrmCreation(Creation):
             col_str_len = int(float(str(col['CHARACTER_MAXIMUM_LENGTH'])))
             if col_str_len > 0:
                 params.append(col_str_len)
-                len_str = f"max_length={col_str_len},"
+                len_str = f"{self.field_options['CHARACTER_MAXIMUM_LENGTH']}={col_str_len},"
                 res = self.combine_param(res=res, param_str=len_str, is_first=self._is_param_first(params))
         except ValueError:
             pass
@@ -148,15 +139,51 @@ class OrmCreation(Creation):
             res = res[:-2] + res[-1]
         return res
 
-    @staticmethod
-    def _is_param_first(params: list):
-        """Only used to determine whether the parameter is the first parameter of the field."""
-        return len(params) <= 1
+
+@dataclass
+class OrmCreation(Creation):
+    """Used to generate orm for tables."""
+    rows: Tuple[str] = (
+        "import orm",
+        "import sqlalchemy\n",
+        "from app.db import database\n",
+        "metadata = sqlalchemy.MetaData()\n\n"
+    )
+
+    def __post_init__(self):
+        self.type_mapping = orm_type_mapping
+        self.field_options = orm_field_options
+        self.col_prefix = 'orm'
+
+    def _class_rows(self, tb_name: str) -> Tuple[str]:
+        return (
+            f"class {self.count_model_name(tb_name=tb_name)}(orm.Model):",
+            f'{space * 4}__tablename__ = "{tb_name}"',
+            f'{space * 4}__database__ = database',
+            f'{space * 4}__metadata__ = metadata\n'
+        )
+
+
+@dataclass
+class TortoiseOrmCreation(Creation):
+    rows: Tuple[str] = (
+        "from tortoise import fields, models\n\n",
+    )
+
+    def __post_init__(self):
+        self.type_mapping = tortoise_type_mapping
+        self.field_options = tortoise_field_options
+        self.col_prefix = 'fields'
+
+    def _class_rows(self, tb_name: str) -> Tuple[str]:
+        return (
+            f"class {self.count_model_name(tb_name=tb_name)}(models.Model):",
+        )
 
 
 @dataclass
 class InterfaceCreation(Creation):
-    _rows: Tuple[str] = (
+    rows: Tuple[str] = (
         "from pydantic import BaseModel\n",
         "from datetime import datetime\n\n"
     )
@@ -164,7 +191,7 @@ class InterfaceCreation(Creation):
     def _class_rows(self, tb_name: str) -> Tuple[str]:
         return f"class {self.count_model_name(tb_name=tb_name)}(BaseModel):",
 
-    def _generate_field(self, col: pd.Series) -> str:
+    def generate_field(self, col: pd.Series) -> str:
         # name / type / default
         col_name: str = col['COLUMN_NAME']
         col_type = col['DATA_TYPE']
